@@ -34,8 +34,6 @@ with open(f"{result_file_name}.json", "w") as f:
     if code_successful:
         result = match.get_result()
 
-    result["seeker_name"] = sys.argv[1]
-    result["hider_name"] = sys.argv[2]
     result["debug"] = debug_message
     json_str = json.dumps(result)
     f.write(json_str)
\ No newline at end of file
